#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_NEGATE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_NEGATE_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/negate.hpp>

#endif
